diff tools/lib64gfx.h @ 2179:8d53da5bf067

Rename DMC64Image::nbanks to nblocks, which reflects better what it does. Also rename dmC64ImageGetNumBanks() to *Blocks().
author Matti Hamalainen <ccr@tnsp.org>
date Wed, 12 Jun 2019 17:55:01 +0300
parents 8e6713705786
children 33cf1b330b7b
line wrap: on
line diff
--- a/tools/lib64gfx.h	Wed Jun 12 17:19:07 2019 +0300
+++ b/tools/lib64gfx.h	Wed Jun 12 17:55:01 2019 +0300
@@ -179,9 +179,10 @@
 {
     DMC64ImageCommonFormat *fmt;
     int laceType,            // Interlace type (D64_ILACE_*)
-        nbanks;              // Number of video banks used
+        nblocks,             // Number of internal blocks used
+        nbanks;              // Number of videobanks used
 
     // Bitmaps, color RAM, screen, etc. blocks * nbanks
     // Not all of them may be allocated
     DMC64MemBlock
         *color,
@@ -342,7 +343,7 @@
 int       dmSetMixedColorC64Palette(DMImage *img);
 
 BOOL      dmCompareAddr16(const DMGrowBuf *buf, const size_t offs, const Uint16 addr);
-int       dmC64ImageGetNumBanks(const DMC64ImageFormat *fmt);
+int       dmC64ImageGetNumBlocks(const DMC64ImageFormat *fmt);
 
 // C64 bitmap image allocation/freeing
 int       dmC64MemBlockAlloc(DMC64MemBlock *blk, const size_t size);
@@ -179,9 +179,10 @@
 
-    // Bitmaps, color RAM, screen, etc. blocks * nbanks
+    // Bitmaps, color RAM, screen, etc. blocks * nblocks
     // Not all of them may be allocated
     DMC64MemBlock